module.exports = defineTest({
	description: 'handles situations where a member expression is deoptimized while being deoptimized'
});
